@@ -1363,3 +1363,142 @@ class SidebarExtension(Extension):
             parser.stream.skip_if('comma')
 
         return CallBlock(self.call_method("_render", args=[List(args)]), [], [], []).set_lineno(lineno)          
+
+
+class PagesExtension(Extension):
+    tags = set(['pages'])
+
+    def __init__(self, environment):
+        super(PagesExtension, self).__init__(environment)
+
+    def _render(self, args, caller=None):
+        logger.info(f'pages Args IN: {args}')
+
+        default = ['page', 10]
+        _ca = len(default)
+        args = args[:_ca] + default[len(args):] + args[_ca:]
+
+        logger.info('pages Args OUT: {0}'.format(args))
+
+        category = args[0]
+        count = int(args[1])
+
+        kwargs = {}
+
+        if 'provider' in category:
+            kwargs = {
+                'provider_tags': 'Bottom',
+                '_sort': [{'rating': {'order': 'desc'}}]
+            }
+        elif 'page' in category:
+            kwargs = {
+                'tags': 'Blog',
+                '_exclude_params': {'tags': 'Promo'},
+                '_sort': [{'publishedon': {'order': 'desc'}}]
+            }
+
+        pages, found = Page.get(
+            is_active=True,
+            is_searchable=True,
+            is_redirect=False,
+            category=category,
+            **kwargs,
+            _source = [
+                "title", 
+                "path", 
+            ], 
+            _count=count,
+        )
+
+        t = current_app.jinja_env.get_template('_ext-pages.html')
+        s = t.render(
+            pages=pages, 
+        )
+        return s
+
+    def parse(self, parser):
+        lineno = next(parser.stream).lineno
+
+        args = []
+        while parser.stream.current.type != 'block_end':
+            args.append(parser.parse_expression())
+            parser.stream.skip_if('comma')
+
+        return CallBlock(self.call_method("_render", args=[List(args)]), [], [], []).set_lineno(lineno)          
+
+
+class PagesListExtension(Extension):
+    tags = set(['pages_list'])
+
+    def __init__(self, environment):
+        super(PagesListExtension, self).__init__(environment)
+
+    def _render(self, args, caller=None):
+        logger.info(f'pages_list Args IN: {args}')
+
+        default = [20, 4]
+        _ca = len(default)
+        args = args[:_ca] + default[len(args):] + args[_ca:]
+
+        logger.info('pages_list Args OUT: {0}'.format(args))
+
+        count = int(args[0])
+        cols = int(args[1])
+
+        pages, found = Page.get(
+            is_active=True,
+            is_searchable=True,
+            is_redirect=False,
+            category=['page', 'category'],
+            tags='Blog',
+            _exclude_params={'tags': 'Promo'},
+            _sort=[{'publishedon': {'order': 'desc'}}],
+            _source = [
+                "title", 
+                "path", 
+                "cover",
+                "publishedon"
+            ], 
+            _count=count,
+        )
+
+        t = current_app.jinja_env.get_template('_ext-pages-list.html')
+        s = t.render(
+            pages=pages, 
+            cols=cols
+        )
+        return s
+
+    def parse(self, parser):
+        lineno = next(parser.stream).lineno
+
+        args = []
+        while parser.stream.current.type != 'block_end':
+            args.append(parser.parse_expression())
+            parser.stream.skip_if('comma')
+
+        return CallBlock(self.call_method("_render", args=[List(args)]), [], [], []).set_lineno(lineno)          
+
+
+class PromoPagesExtension(Extension):
+    tags = set(['promo_pages'])
+
+    def __init__(self, environment):
+        super(PromoPagesExtension, self).__init__(environment)
+
+    def _render(self, caller):
+        t = current_app.jinja_env.get_template('_ext-promo_pages.html')
+        pages = [
+            {'path': '/blog/best-bitcoin-casinos/', 'icon': 'vpns', 'title': 'Best Bitcoin <br/>Casinos'},
+            {'path': '/blog/best-ethereum-casinos/', 'icon': 'vpns', 'title': 'Best Ethereum <br/>Casinos'},
+            {'path': '/blog/best-casino-games/', 'icon': 'vpns', 'title': 'Best Casino <br/>Games'},
+            {'path': '/blog/casino-of-the-month/', 'icon': 'vpns', 'title': 'Casino <br/>of the Month'},
+            {'path': '/blog/best-vpns/', 'icon': 'vpns', 'title': 'Best <br/>VPN\'s'},
+            {'path': '/blog/the-uk-casinos/', 'icon': 'vpns', 'title': 'Best Casino <br/>in the UK'},
+        ]
+        s = t.render(pages=pages)
+        return s
+
+    def parse(self, parser):
+        lineno = next(parser.stream).lineno
+        return CallBlock(self.call_method("_render", []), [], [], '').set_lineno(lineno)
