@@ -735,7 +735,7 @@ class Page(ElasticEntity):
                 'licences:select:licences', 
                 'provider_tags:select:provider_tags', 
                 'languages:select:languages', 
-                'support_languages:select:support_languages',
+                'support_languages:select:languages',
                 'currencies:select:currency',
                 'operator:str', 
                 'affiliate:str', 
